@@ -13,7 +13,7 @@ import (
 	"github.com/superfly/flyctl/iostreams"
 )
 
-//go:embed templates templates/*/.dockerignore templates/**/.fly
+//go:embed templates templates/*/.dockerignore templates/**/.fly templates/**/.github
 var content embed.FS
 
 type InitCommand struct {
@@ -73,6 +73,7 @@ type SourceInfo struct {
 	PostgresInitCommandCondition bool
 	DatabaseDesired              DatabaseKind
 	RedisDesired                 bool
+	GitHubActions                GitHubActionsStruct
 	ObjectStorageDesired         bool
 	Concurrency                  map[string]int
 	Callback                     func(appName string, srcInfo *SourceInfo, plan *plan.LaunchPlan, flags []string) error
@@ -99,6 +100,12 @@ type ScannerConfig struct {
 	Colorize     *iostreams.ColorScheme
 }
 
+type GitHubActionsStruct struct {
+	Deploy  bool
+	Secrets bool
+	Files   []SourceFile
+}
+
 func Scan(sourceDir string, config *ScannerConfig) (*SourceInfo, error) {
 	scanners := []sourceScanner{
 		configureDjango,
@@ -133,6 +140,7 @@ func Scan(sourceDir string, config *ScannerConfig) (*SourceInfo, error) {
 			return nil, err
 		}
 		if si != nil {
+			github_actions(sourceDir, &si.GitHubActions)
 			return si, nil
 		}
 	}
@@ -182,10 +190,6 @@ func templatesFilter(name string, filter func(input []byte) []byte) (files []Sou
 			return err
 		}
 
-		if err != nil {
-			return err
-		}
-
 		f := SourceFile{
 			Path:     relPath,
 			Contents: filter(data),
